pub fn set_current_iterate(snapshot: Option<IterateSnapshot>)Expand description
Store a snapshot of the current iterate for GetCurrentIterate/Violations access.
pub fn set_current_iterate(snapshot: Option<IterateSnapshot>)Store a snapshot of the current iterate for GetCurrentIterate/Violations access.